@@ -12,10 +12,10 @@ from gi.repository import GdkPixbuf
 from gi.repository import Gtk
 
 from kuwo import Config
+_ = Config._
 from kuwo import Net
 from kuwo import Widgets
-
-_ = Config._
+from kuwo.log import logger
 
 
 class InfoLabel(Gtk.Label):
@@ -50,12 +50,12 @@ class ArtistButton(Gtk.RadioButton):
             return
         self.parent.artist_notebook.set_current_page(self.tab)
         methods = [
-                self.parent.show_artist_songs,
-                self.parent.show_artist_albums,
-                self.parent.show_artist_mv,
-                self.parent.show_artist_similar,
-                self.parent.show_artist_info,
-                ]
+            self.parent.show_artist_songs,
+            self.parent.show_artist_albums,
+            self.parent.show_artist_mv,
+            self.parent.show_artist_similar,
+            self.parent.show_artist_info,
+        ]
         methods[self.tab]()
 
 
@@ -99,8 +99,8 @@ class Artists(Gtk.Box):
         # control box for artist's mv
         # pic, name, artist, album, rid, artistid, albumid, tooltip
         # FIXME: check formats column
-        self.artist_mv_liststore = Gtk.ListStore(
-                GdkPixbuf.Pixbuf, str, str, str, int, int, int, str)
+        self.artist_mv_liststore = Gtk.ListStore(GdkPixbuf.Pixbuf, str, str,
+                                                 str, int, int, int, str)
         self.artist_mv_control_box = Widgets.MVControlBox(
                 self.artist_mv_liststore, app)
         self.buttonbox.pack_end(self.artist_mv_control_box, False, False, 0)
@@ -108,8 +108,8 @@ class Artists(Gtk.Box):
         # control box for artist's albums
         album_songs_treeview = Widgets.TreeViewSongs(app)
         self.album_songs_liststore = album_songs_treeview.liststore
-        self.album_control_box = Widgets.ControlBox(
-                self.album_songs_liststore, app)
+        self.album_control_box = Widgets.ControlBox(self.album_songs_liststore,
+                                                    app)
         self.buttonbox.pack_end(self.album_control_box, False, False, 0)
 
         # main notebook
@@ -159,16 +159,15 @@ class Artists(Gtk.Box):
 
         # main window of artists
         self.artists_win = Gtk.ScrolledWindow()
-        self.artists_win.get_vadjustment().connect(
-                'value-changed', self.on_artists_win_scrolled)
+        adjustment = self.artists_win.get_vadjustment()
+        adjustment.connect('value-changed', self.on_artists_win_scrolled)
         self.artists_tab.pack_start(self.artists_win, True, True, 0)
         # icon, artist name, artist id, num of songs, tooltip
-        self.artists_liststore = Gtk.ListStore(
-                GdkPixbuf.Pixbuf, str, int, str, str)
-        artists_iconview = Widgets.IconView(
-                self.artists_liststore, tooltip=4)
-        artists_iconview.connect(
-                'item_activated', self.on_artists_iconview_item_activated)
+        self.artists_liststore = Gtk.ListStore(GdkPixbuf.Pixbuf, str, int,
+                                               str, str)
+        artists_iconview = Widgets.IconView(self.artists_liststore, tooltip=4)
+        artists_iconview.connect('item_activated',
+                                 self.on_artists_iconview_item_activated)
         self.artists_win.add(artists_iconview)
 
         # Artist tab (tab 1)
@@ -176,21 +175,20 @@ class Artists(Gtk.Box):
         self.notebook.append_page(self.artist_tab, Gtk.Label(_('Artist')))
 
         # left panel of artist
-        self.artist_buttons = Gtk.Box(
-                spacing=5, orientation=Gtk.Orientation.VERTICAL)
+        self.artist_buttons = Gtk.Box(spacing=5,
+                                      orientation=Gtk.Orientation.VERTICAL)
         self.artist_buttons.props.margin_top = 15
         self.artist_tab.pack_start(self.artist_buttons, False, False, 0)
 
-        self.artist_songs_button = ArtistButton(
-                self, _('Songs'), None, 0)
-        self.artist_albums_button = ArtistButton(
-                self, _('Albums'), self.artist_songs_button, 1)
-        self.artist_mv_button = ArtistButton(
-                self, _('MV'), self.artist_songs_button, 2)
-        self.artist_similar_button = ArtistButton(
-                self, _('Similar'), self.artist_songs_button, 3)
-        self.artist_info_button = ArtistButton(
-                self, _('Info'), self.artist_songs_button, 4)
+        self.artist_songs_button = ArtistButton(self, _('Songs'), None, 0)
+        self.artist_albums_button = ArtistButton(self, _('Albums'),
+                                                 self.artist_songs_button, 1)
+        self.artist_mv_button = ArtistButton(self, _('MV'),
+                                             self.artist_songs_button, 2)
+        self.artist_similar_button = ArtistButton(self, _('Similar'),
+                                                  self.artist_songs_button, 3)
+        self.artist_info_button = ArtistButton(self, _('Info'),
+                                               self.artist_songs_button, 4)
 
         # Add fav_btn to artist_tab
         fav_curr_artist_btn = Gtk.Button()
@@ -199,10 +197,9 @@ class Artists(Gtk.Box):
         fav_curr_artist_btn.props.image = self.fav_no_img
         if not Config.GTK_LE_36:
             fav_curr_artist_btn.props.always_show_image = True
-        fav_curr_artist_btn.set_tooltip_text(
-                _('Add to favorite artists list'))
-        fav_curr_artist_btn.connect(
-                'clicked', self.on_fav_curr_artist_btn_clicked)
+        fav_curr_artist_btn.set_tooltip_text(_('Add to favorite artists list'))
+        fav_curr_artist_btn.connect('clicked',
+                                    self.on_fav_curr_artist_btn_clicked)
         self.artist_buttons.pack_start(fav_curr_artist_btn, False, False, 0)
         self.fav_curr_artist_btn = fav_curr_artist_btn
 
@@ -213,46 +210,44 @@ class Artists(Gtk.Box):
 
         # songs tab for artist (tab 0)
         self.artist_songs_tab = Gtk.ScrolledWindow()
-        self.artist_notebook.append_page(
-                self.artist_songs_tab, Gtk.Label(_('Songs')))
+        self.artist_notebook.append_page(self.artist_songs_tab,
+                                         Gtk.Label(_('Songs')))
         self.artist_songs_tab.add(artist_songs_treeview)
 
 
         # albums tab for artist (tab 1)
         self.artist_albums_tab = Gtk.ScrolledWindow()
-        self.artist_notebook.append_page(
-                self.artist_albums_tab, Gtk.Label(_('Albums')))
+        self.artist_notebook.append_page(self.artist_albums_tab,
+                                         Gtk.Label(_('Albums')))
         # pic, album, albumid, artist, artistid, info/tooltip
-        self.artist_albums_liststore = Gtk.ListStore(
-                GdkPixbuf.Pixbuf, str, int, str, int, str)
-        artist_albums_iconview = Widgets.IconView(
-                self.artist_albums_liststore, tooltip=5)
-        artist_albums_iconview.connect(
-                'item_activated',
+        self.artist_albums_liststore = Gtk.ListStore(GdkPixbuf.Pixbuf, str,
+                                                     int, str, int, str)
+        artist_albums_iconview = Widgets.IconView(self.artist_albums_liststore,
+                                                  tooltip=5)
+        artist_albums_iconview.connect('item_activated',
                 self.on_artist_albums_iconview_item_activated)
         self.artist_albums_tab.add(artist_albums_iconview)
 
         # MVs tab for artist (tab 2)
         self.artist_mv_tab = Gtk.ScrolledWindow()
-        self.artist_notebook.append_page(
-                self.artist_mv_tab, Gtk.Label(_('MV')))
-        artist_mv_iconview = Widgets.IconView(
-                self.artist_mv_liststore, info_pos=2, tooltip=7)
-        artist_mv_iconview.connect(
-                'item_activated', self.on_artist_mv_iconview_item_activated)
+        self.artist_notebook.append_page(self.artist_mv_tab,
+                                         Gtk.Label(_('MV')))
+        artist_mv_iconview = Widgets.IconView(self.artist_mv_liststore,
+                                              info_pos=2, tooltip=7)
+        artist_mv_iconview.connect('item_activated',
+                                   self.on_artist_mv_iconview_item_activated)
         self.artist_mv_tab.add(artist_mv_iconview)
 
         # Similar tab for artist (tab 3)
         self.artist_similar_tab = Gtk.ScrolledWindow()
-        self.artist_notebook.append_page(
-                self.artist_similar_tab, Gtk.Label(_('Similar')))
+        self.artist_notebook.append_page(self.artist_similar_tab,
+                                         Gtk.Label(_('Similar')))
         # pic, artist name, artist id, num of songs, tooltip
-        self.artist_similar_liststore = Gtk.ListStore(
-                GdkPixbuf.Pixbuf, str, int, str, str)
+        self.artist_similar_liststore = Gtk.ListStore(GdkPixbuf.Pixbuf, str,
+                                                      int, str, str)
         artist_similar_iconview = Widgets.IconView(
                 self.artist_similar_liststore, tooltip=4)
-        artist_similar_iconview.connect(
-                'item_activated',
+        artist_similar_iconview.connect('item_activated',
                 self.on_artist_similar_iconview_item_activated)
         self.artist_similar_tab.add(artist_similar_iconview)
 
@@ -262,10 +257,9 @@ class Artists(Gtk.Box):
         artist_info_tab.add(artist_info_tab_vp)
         artist_info_tab.props.margin_left = 20
         artist_info_tab.props.margin_top = 5
-        self.artist_notebook.append_page(
-                artist_info_tab, Gtk.Label(_('Info')))
-        artist_info_box = Gtk.Box(
-                spacing=10, orientation=Gtk.Orientation.VERTICAL)
+        self.artist_notebook.append_page(artist_info_tab, Gtk.Label(_('Info')))
+        artist_info_box = Gtk.Box(spacing=10,
+                                  orientation=Gtk.Orientation.VERTICAL)
         artist_info_box.props.margin_right = 10
         artist_info_box.props.margin_bottom = 10
         artist_info_tab_vp.add(artist_info_box)
@@ -281,24 +275,23 @@ class Artists(Gtk.Box):
         artist_info_grid = Gtk.Grid()
         artist_info_grid.props.row_spacing = 10
         artist_info_grid.props.column_spacing = 30
-        self.artist_info_name = InfoLabel(
-                artist_info_grid, _('Name'), 0, 0)
-        self.artist_info_birthday = InfoLabel(
-                artist_info_grid, _('Birthday'), 0, 1)
-        self.artist_info_birthplace = InfoLabel(
-                artist_info_grid, _('Birthplace'), 1, 1)
-        self.artist_info_height = InfoLabel(
-                artist_info_grid, _('Height'), 0, 2)
-        self.artist_info_weight = InfoLabel(
-                artist_info_grid, _('Weight'), 1, 2)
-        self.artist_info_country = InfoLabel(
-                artist_info_grid, _('Country'), 0, 3)
-        self.artist_info_language = InfoLabel(
-                artist_info_grid, _('Language'), 1, 3)
-        self.artist_info_gender = InfoLabel(
-                artist_info_grid, _('Gender'), 0, 4)
-        self.artist_info_constellation = InfoLabel(
-                artist_info_grid, _('Constellation'), 1, 4)
+        self.artist_info_name = InfoLabel(artist_info_grid, _('Name'), 0, 0)
+        self.artist_info_birthday = InfoLabel(artist_info_grid,
+                                              _('Birthday'), 0, 1)
+        self.artist_info_birthplace = InfoLabel(artist_info_grid,
+                                                _('Birthplace'), 1, 1)
+        self.artist_info_height = InfoLabel(artist_info_grid,
+                                            _('Height'), 0, 2)
+        self.artist_info_weight = InfoLabel(artist_info_grid,
+                                            _('Weight'), 1, 2)
+        self.artist_info_country = InfoLabel(artist_info_grid,
+                                             _('Country'), 0, 3)
+        self.artist_info_language = InfoLabel(artist_info_grid,
+                                              _('Language'), 1, 3)
+        self.artist_info_gender = InfoLabel(artist_info_grid,
+                                            _('Gender'), 0, 4)
+        self.artist_info_constellation = InfoLabel(artist_info_grid,
+                                                   _('Constellation'), 1, 4)
         artist_info_hbox.pack_start(artist_info_grid, False, False, 0)
 
         artist_info_textview = Gtk.TextView()
@@ -327,40 +320,41 @@ class Artists(Gtk.Box):
         fav_win = Gtk.ScrolledWindow()
         fav_artists_tab.pack_start(fav_win, True, True, 0)
         # icon, artist name, artist id, tooltip
-        self.fav_artists_liststore = Gtk.ListStore(
-                GdkPixbuf.Pixbuf, str, int, str)
-        fav_artists_iconview = Widgets.IconView(
-                self.fav_artists_liststore, info_pos=None, tooltip=3)
+        self.fav_artists_liststore = Gtk.ListStore(GdkPixbuf.Pixbuf,
+                                                   str, int, str)
+        fav_artists_iconview = Widgets.IconView(self.fav_artists_liststore,
+                                                info_pos=None, tooltip=3)
         fav_artists_iconview.connect('item_activated',
                 self.on_fav_artists_iconview_item_activated)
         fav_win.add(fav_artists_iconview)
 
-        prefs = ((_('All'), ''),
-                ('A', 'a'), ('B', 'b'), ('C', 'c'), ('D', 'd'),
-                ('E', 'e'), ('F', 'f'), ('G', 'g'), ('H', 'h'), ('I', 'i'),
-                ('J', 'j'), ('K', 'k'), ('L', 'l'), ('M', 'm'), ('N', 'n'),
-                ('O', 'o'), ('P', 'p'), ('Q', 'q'), ('R', 'r'), ('S', 's'),
-                ('T', 't'), ('U', 'u'), ('V', 'v'), ('W', 'w'), ('X', 'x'),
-                ('Y', 'y'), ('Z', 'z'), ('#', '%26'),
-                )
+        prefs = (
+            (_('All'), ''),
+            ('A', 'a'), ('B', 'b'), ('C', 'c'), ('D', 'd'),
+            ('E', 'e'), ('F', 'f'), ('G', 'g'), ('H', 'h'), ('I', 'i'),
+            ('J', 'j'), ('K', 'k'), ('L', 'l'), ('M', 'm'), ('N', 'n'),
+            ('O', 'o'), ('P', 'p'), ('Q', 'q'), ('R', 'r'), ('S', 's'),
+            ('T', 't'), ('U', 'u'), ('V', 'v'), ('W', 'w'), ('X', 'x'),
+            ('Y', 'y'), ('Z', 'z'), ('#', '%26'),
+        )
         for pref in prefs:
             self.pref_liststore.append(pref)
         self.pref_combo.set_active(0)
         self.pref_combo.connect('changed', self.on_cate_changed)
 
         cates = (
-                (_('Hot Artists'), 0),
-                (_('Chinese Male'), 1),
-                (_('Chinese Female'), 2),
-                (_('Chinese Band'), 3),
-                (_('Japanese Male'), 4),
-                (_('Japanese Female'), 5),
-                (_('Japanese Band'), 6),
-                (_('European Male'), 7),
-                (_('European Female'), 8),
-                (_('European Band'), 9),
-                (_('Others'), 10),
-                )
+            (_('Hot Artists'), 0),
+            (_('Chinese Male'), 1),
+            (_('Chinese Female'), 2),
+            (_('Chinese Band'), 3),
+            (_('Japanese Male'), 4),
+            (_('Japanese Female'), 5),
+            (_('Japanese Band'), 6),
+            (_('European Male'), 7),
+            (_('European Female'), 8),
+            (_('European Band'), 9),
+            (_('Others'), 10),
+        )
         for cate in cates:
             self.cate_liststore.append(cate)
         selection = self.cate_treeview.get_selection()
@@ -387,6 +381,8 @@ class Artists(Gtk.Box):
         def on_append_artists(info, error=None):
             artists, self.artists_total = info
             if error or not self.artists_total or not artists:
+                logger.error('append_artists(), %s, %s, %s' %
+                             (self.artists_total, artists, error))
                 return
             urls = []
             tree_iters = []
@@ -398,13 +394,14 @@ class Artists(Gtk.Box):
                     int(artist['id']),
                     _info,
                     Widgets.set_tooltip(artist['name'], _info),
-                    ])
+                ])
                 urls.append(artist['pic'])
                 tree_iters.append(tree_iter)
-            Net.update_artist_logos(
-                    self.artists_liststore, 0, tree_iters, urls)
+            Net.async_call(Net.update_artist_logos, self.artists_liststore, 0,
+                           tree_iters, urls)
 
         if init:
+            self.artists_win.get_vscrollbar().set_value(0)
             self.artists_liststore.clear()
             self.artists_page = 0
             self.artists_win.get_vadjustment().set_value(0)
@@ -418,9 +415,8 @@ class Artists(Gtk.Box):
         pref_index = self.pref_combo.get_active()
         catid = model[_iter][1]
         prefix = self.pref_liststore[pref_index][1]
-        Net.async_call(
-                Net.get_artists, on_append_artists, catid,
-                self.artists_page, prefix)
+        Net.async_call(Net.get_artists, catid, self.artists_page, prefix,
+                       callback=on_append_artists)
 
     def on_artists_iconview_item_activated(self, iconview, path):
         model = iconview.get_model()
@@ -436,7 +432,7 @@ class Artists(Gtk.Box):
     # scrolled windows
     def on_artists_win_scrolled(self, adj):
         if (Widgets.reach_scrolled_bottom(adj) and 
-            self.artists_page < self.artists_total - 1):
+                self.artists_page < self.artists_total - 1):
             self.artists_page += 1
             self.append_artists()
 
@@ -486,6 +482,8 @@ class Artists(Gtk.Box):
         def _append_artist_songs(songs_args, error=None):
             songs, self.artist_songs_total = songs_args
             if error or self.artist_songs_total == 0:
+                logger.error('append_artist_songs(): %s, %s' %
+                             (self.artist_songs_total, error))
                 return
             for song in songs:
                 self.artist_songs_liststore.append([
@@ -504,11 +502,11 @@ class Artists(Gtk.Box):
                 self.append_artist_songs()
 
         if init:
+            self.artist_songs_tab.get_vscrollbar().set_value(0)
             self.artist_songs_liststore.clear()
             self.artist_songs_page = 0
-        Net.async_call(
-                Net.get_artist_songs_by_id, _append_artist_songs, 
-                self.curr_artist_id, self.artist_songs_page)
+        Net.async_call(Net.get_artist_songs_by_id, self.curr_artist_id,
+                       self.artist_songs_page, callback=_append_artist_songs)
 
     def show_artist_albums(self):
         self.artist_control_box.hide()
@@ -523,6 +521,8 @@ class Artists(Gtk.Box):
         def _append_artist_albums(albums_args, error=None):
             albums, self.artist_albums_total = albums_args
             if error or self.artist_albums_total == 0:
+                logger.error('append_arttist_albums(): %s, %s' %
+                             (self.artist_albums_taotal, error))
                 return
             urls = []
             tree_iters = []
@@ -537,20 +537,20 @@ class Artists(Gtk.Box):
                 ])
                 urls.append(album['pic'])
                 tree_iters.append(tree_iter)
-            Net.update_album_covers(
-                    self.artist_albums_liststore, 0, tree_iters, urls)
+            Net.async_call(Net.update_album_covers,
+                           self.artist_albums_liststore, 0, tree_iters, urls)
             self.artist_albums_page += 1
             if self.artist_albums_page < self.artist_albums_total - 1:
                 self.append_artist_albums()
 
         if init:
+            self.artist_albums_tab.get_vscrollbar().set_value(0)
             self.artist_albums_liststore.clear()
             self.artist_albums_page = 0
         if init or not hasattr(self.artist_albums, 'timestamp'):
             self.artist_albums_liststore.timestamp = time.time()
-        Net.async_call(
-                Net.get_artist_albums, _append_artist_albums,
-                self.curr_artist_id, self.artist_albums_page)
+        Net.async_call(Net.get_artist_albums, self.curr_artist_id,
+                       self.artist_albums_page, callback=_append_artist_albums)
 
     def show_artist_mv(self):
         self.artist_control_box.hide()
@@ -565,6 +565,8 @@ class Artists(Gtk.Box):
         def _append_artist_mv(mv_args, error=None):
             mvs, self.artist_mv_total = mv_args
             if error or self.artist_mv_total == 0:
+                logger.error('append_artist_mv(): %s, %s' %
+                             (self.artist_mv_total, error))
                 return
             urls = []
             tree_iters = []
@@ -578,23 +580,23 @@ class Artists(Gtk.Box):
                     int(mv['artistid']),
                     0,
                     Widgets.set_tooltip(mv['name'], mv['artist']),
-                    ])
+                ])
                 tree_iters.append(tree_iter)
                 urls.append(mv['pic'])
-            Net.update_mv_images(
-                    self.artist_mv_liststore, 0, tree_iters, urls)
+            Net.async_call(Net.update_mv_images, self.artist_mv_liststore, 0,
+                           tree_iters, urls)
             self.artist_mv_page += 1
             if self.artist_mv_page < self.artist_mv_total - 1:
                 self.append_artist_mv()
 
         if init:
+            self.artist_mv_tab.get_vscrollbar().set_value(0)
             self.artist_mv_liststore.clear()
             self.artist_mv_page = 0
         if init or not hasattr(self.artist_mv_liststore, 'timestamp'):
             self.artist_mv_liststore.timestamp = time.time()
-        Net.async_call(
-                Net.get_artist_mv, _append_artist_mv,
-                self.curr_artist_id, self.artist_mv_page)
+        Net.async_call(Net.get_artist_mv, self.curr_artist_id,
+                       self.artist_mv_page, callback=_append_artist_mv)
 
     def show_artist_similar(self):
         self.artist_control_box.hide()
@@ -610,6 +612,8 @@ class Artists(Gtk.Box):
         def _append_artist_similar(similar_args, error=None):
             artists, self.artist_similar_total = similar_args
             if error or not self.artist_similar_total:
+                logger.error('append_artist_similar(): %s, %s' %
+                             (self.artist_similar_total, error))
                 return
             urls = []
             tree_iters = []
@@ -621,23 +625,24 @@ class Artists(Gtk.Box):
                     int(artist['id']),
                     _info,
                     Widgets.set_tooltip(artist['name'], _info),
-                    ])
+                ])
                 urls.append(artist['pic'])
                 tree_iters.append(tree_iter)
-            Net.update_artist_logos(
-                    self.artist_similar_liststore, 0, tree_iters, urls)
+            Net.async_call(Net.update_artist_logos,
+                           self.artist_similar_liststore, 0, tree_iters, urls)
             self.artist_similar_page += 1
             if self.artist_similar_page < self.artist_similar_total - 1:
                 self.append_artist_similar()
 
         if init:
+            self.artist_similar_tab.get_vscrollbar().set_value(0)
             self.artist_similar_liststore.clear()
             self.artist_similar_page = 0
         if init or not hasattr(self.artist_similar_liststore, 'timestamp'):
             self.artist_similar_liststore.timestamp = time.time()
-        Net.async_call(
-                Net.get_artist_similar, _append_artist_similar,
-                self.curr_artist_id, self.artist_similar_page)
+        Net.async_call(Net.get_artist_similar, self.curr_artist_id,
+                       self.artist_similar_page,
+                       callback=_append_artist_similar)
 
     def show_artist_info(self):
         self.artist_control_box.hide()
@@ -651,6 +656,7 @@ class Artists(Gtk.Box):
     def append_artist_info(self):
         def _append_artist_info(info, error=None):
             if error or not info:
+                logger.error('appen_artist_info(): %s, %s' % (info, error))
                 return
             if info.get('pic', None):
                 self.artist_info_pic.set_from_file(info['pic'])
@@ -669,9 +675,8 @@ class Artists(Gtk.Box):
             else:
                 self.artist_info_textbuffer.set_text('')
 
-        Net.async_call(
-                Net.get_artist_info, _append_artist_info,
-                self.curr_artist_id)
+        Net.async_call(Net.get_artist_info, self.curr_artist_id,
+                       callback=_append_artist_info)
 
 
     def on_artist_albums_iconview_item_activated(self, iconview, path):
@@ -714,6 +719,7 @@ class Artists(Gtk.Box):
     def append_album_songs(self):
         def _append_album_songs(songs, error=None):
             if error or not songs:
+                logger.error('append_album_songs(): %s, %s' % (songs, error))
                 return
             for song in songs:
                 self.album_songs_liststore.append([
@@ -727,9 +733,8 @@ class Artists(Gtk.Box):
                     song['formats'],
                 ])
         self.album_songs_liststore.clear()
-        Net.async_call(
-                Net.get_album, _append_album_songs,
-                self.curr_album_id)
+        Net.async_call(Net.get_album, self.curr_album_id,
+                       callback=_append_album_songs)
 
     def on_artist_button_clicked(self, button):
         self.show_artist(self.curr_artist_name, self.curr_artist_id)
@@ -738,19 +743,21 @@ class Artists(Gtk.Box):
     def add_to_fav_artists(self, artist_id, init=False):
         def _append_fav_artist(info, error=None):
             if error or not info:
+                logger.error('add_to_fav_artists(): %s, %s' % (info, error))
                 return
             if info.get('pic', None):
-                pix = GdkPixbuf.Pixbuf.new_from_file_at_size(
-                        info['pic'], 100, 100)
+                pix = GdkPixbuf.Pixbuf.new_from_file_at_size(info['pic'],
+                                                             100, 100)
             else:
                 pix = self.app.theme['anonymous']
             tip = Widgets.escape(info.get('info', ''))
-            self.fav_artists_liststore.append(
-                    [pix, info['name'], artist_id, tip])
+            self.fav_artists_liststore.append([pix, info['name'],
+                                               artist_id, tip])
 
-        if init is False and self.check_artist_favorited(artist_id):
+        if not init and self.check_artist_favorited(artist_id):
             return
-        Net.async_call(Net.get_artist_info, _append_fav_artist, artist_id)
+        Net.async_call(Net.get_artist_info, artist_id,
+                       callback=_append_fav_artist)
 
     def remove_from_fav_artists(self, artist_id):
         '''Remove an artist from fav_artists_liststore.'''
