@@ -15,10 +15,10 @@ from gi.repository import Gtk
 from gi.repository import Pango
 
 from kuwo import Config
+_ = Config._
 from kuwo import Net
 from kuwo import Widgets
-
-_ = Config._
+from kuwo.log import logger
 
 class RadioItem(Gtk.EventBox):
     def __init__(self, radio_id, app):
@@ -39,18 +39,18 @@ class RadioItem(Gtk.EventBox):
 
         self.img = Gtk.Image()
         self.img_path = Net.get_image(self.playlists[self.radio_id]['pic'])
-        self.small_pix = GdkPixbuf.Pixbuf.new_from_file_at_size(
-                self.img_path, 50, 50)
-        self.big_pix = GdkPixbuf.Pixbuf.new_from_file_at_size(
-                self.img_path, 75, 75)
+        self.small_pix = GdkPixbuf.Pixbuf.new_from_file_at_size(self.img_path,
+                                                                50, 50)
+        self.big_pix = GdkPixbuf.Pixbuf.new_from_file_at_size(self.img_path,
+                                                              75, 75)
         self.img.set_from_pixbuf(self.small_pix)
         self.box.pack_start(self.img, False, False, 0)
 
         box_right = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         self.box.pack_start(box_right, True, True, 0)
 
-        radio_name = Gtk.Label(Widgets.short_str(
-                self.playlists[self.radio_id]['name'], 8))
+        radio_name = Gtk.Label(
+                Widgets.short_str(self.playlists[self.radio_id]['name'], 8))
         box_right.pack_start(radio_name, True, True, 0)
 
         self.label = Gtk.Label(_('song name'))
@@ -83,29 +83,27 @@ class RadioItem(Gtk.EventBox):
     
     def init_songs(self):
         def _update_songs(songs, error=None):
-            if not songs:
+            if error or not songs:
+                logger.error('init_songs(): %s, %s' % (songs, error))
                 return
             self.playlists[self.radio_id]['songs'] = songs
             self.playlists[self.radio_id]['curr_song'] = 0
             self.update_label()
         if len(self.playlists[self.radio_id]['songs']) == 0:
-            Net.async_call(Net.get_radio_songs, _update_songs, 
-                           self.radio_id,
-                           self.playlists[self.radio_id]['offset'])
+            Net.async_call(Net.get_radio_songs, self.radio_id,
+                           self.playlists[self.radio_id]['offset'],
+                           callback=_update_songs)
     
     def load_more_songs(self):
         def _on_more_songs_loaded(songs, error=None):
             if error or not songs:
+                logger.error('load_more_songs(): %s, %s' % (songs, error))
                 return
-            songs2 = []
-            for song in songs:
-                song['formats'] = ''
-                songs2.append(song)
-            self.playlists[self.radio_id]['songs'] += songs2
+            self.playlists[self.radio_id]['songs'] += songs
         self.playlists[self.radio_id]['offset'] += 1
-        Net.async_call(Net.get_radio_songs, _on_more_songs_loaded, 
-                       self.playlists[self.radio_id],
-                       self.playlists[self.radio_id]['offset'])
+        Net.async_call(Net.get_radio_songs, self.playlists[self.radio_id],
+                       self.playlists[self.radio_id]['offset'],
+                       callback=_on_more_songs_loaded)
 
     def expand(self):
         if self.expanded:
@@ -212,12 +210,11 @@ class Radio(Gtk.Box):
         self.pack_start(self.scrolled_radios, True, True, 0)
 
         # pic, name, id, num of listeners, pic_url, tooltip
-        self.liststore_radios = Gtk.ListStore(
-                GdkPixbuf.Pixbuf, str, int, str, str, str)
-        iconview_radios = Widgets.IconView(
-                self.liststore_radios, tooltip=5)
-        iconview_radios.connect(
-                'item_activated', self.on_iconview_radios_item_activated)
+        self.liststore_radios = Gtk.ListStore(GdkPixbuf.Pixbuf, str, int,
+                                              str, str, str)
+        iconview_radios = Widgets.IconView(self.liststore_radios, tooltip=5)
+        iconview_radios.connect('item_activated',
+                                self.on_iconview_radios_item_activated)
         self.scrolled_radios.add(iconview_radios)
 
         self.show_all()
@@ -237,12 +234,12 @@ class Radio(Gtk.Box):
                 Widgets.unescape(radio['info']),
                 radio['pic'],
                 Widgets.set_tooltip(radio['disname'], radio['info']),
-                ])
+            ])
             tree_iters.append(tree_iter)
             urls.append(radio['pic'])
         self.liststore_radios.timestamp = time.time()
-        Net.update_liststore_images(
-                self.liststore_radios, 0, tree_iters, urls)
+        Net.async_call(Net.update_liststore_images, self.liststore_radios, 0,
+                       tree_iters, urls)
 
         for radio_rid in self.playlists:
             radio_item = RadioItem(radio_rid, self.app)
@@ -282,13 +279,13 @@ class Radio(Gtk.Box):
     def on_iconview_radios_item_activated(self, iconview, path):
         model = iconview.get_model()
         radio_info = {
-                'name': model[path][1],
-                'radio_id': model[path][2],
-                'pic': model[path][4],
-                'offset': 0,
-                'curr_song': 0,
-                'songs': [],
-                }
+            'name': model[path][1],
+            'radio_id': model[path][2],
+            'pic': model[path][4],
+            'offset': 0,
+            'curr_song': 0,
+            'songs': [],
+        }
         self.append_radio(radio_info)
 
     def append_radio(self, radio_info):
